--[[
Don't edit or remove this comment block! It is used by the editor to store information since i'm too lazy to write a good LUA parser... -Haz
SETTINGS
RestrictedEnhancements=
RestrictedCategories=
END
--]]

local ScenarioUtils = import('/lua/sim/ScenarioUtilities.lua')
local ScenarioFramework = import('/lua/ScenarioFramework.lua')

# Resource Scale Script written by Jotto
function ScenarioUtils.CreateResources()
  local markers = ScenarioUtils.GetMarkers()
  for i, tblData in pairs(markers) do
    if tblData.resource and not tblData.SpawnWithArmy then
      CreateResourceDeposit(
        tblData.type,
        tblData.position[1], tblData.position[2], tblData.position[3],
        tblData.size
      )
      local albedo, sx, sz, lod
      if tblData.type == "Mass" then
        albedo = "/env/common/splats/mass_marker.dds"
        sx = 2
        sz = 2
        lod = 100
        CreatePropHPR(
          '/env/common/props/massDeposit01_prop.bp',
          tblData.position[1], tblData.position[2], tblData.position[3],
          Random(0,360), 0, 0
        )
      else
        albedo = "/env/common/splats/hydrocarbon_marker.dds"
        sx = 6
        sz = 6
        lod = 200
        CreatePropHPR(
          '/env/common/props/hydrocarbonDeposit01_prop.bp',
          tblData.position[1], tblData.position[2], tblData.position[3],
          Random(0,360), 0, 0
        )
      end
      CreateSplat(
        tblData.position,           # Position
        0,                          # Heading (rotation)
        albedo,                     # Texture name for albedo
        sx, sz,                     # SizeX/Z
        lod,                        # LOD
        0,                          # Duration (0 == does not expire)
        -1,                         # army (-1 == not owned by any single army)
        0
      )
    elseif tblData.resource and tblData.SpawnWithArmy then
      for a, v in ListArmies() do
        if tblData.SpawnWithArmy == v then
          CreateResourceDeposit(
            tblData.type,
            tblData.position[1], tblData.position[2], tblData.position[3],
            tblData.size
          )
          local albedo, sx, sz, lod
          if tblData.type == "Mass" then
            albedo = "/env/common/splats/mass_marker.dds"
            sx = 2
            sz = 2
            lod = 100
            CreatePropHPR(
              '/env/common/props/massDeposit01_prop.bp',
              tblData.position[1], tblData.position[2], tblData.position[3],
              Random(0,360), 0, 0
            )
          else
            albedo = "/env/common/splats/hydrocarbon_marker.dds"
            sx = 6
            sz = 6
            lod = 200
            CreatePropHPR(
              '/env/common/props/hydrocarbonDeposit01_prop.bp',
              tblData.position[1], tblData.position[2], tblData.position[3],
              Random(0,360), 0, 0
            )
          end
          CreateSplat(
            tblData.position,           # Position
            0,                          # Heading (rotation)
            albedo,                     # Texture name for albedo
            sx, sz,                     # SizeX/Z
            lod,                        # LOD
            0,                          # Duration (0 == does not expire)
            -1,                         # army (-1 == not owned by any single army)
            0
          )
        end
      end
    end
  end
end

function OnPopulate()
  ScenarioUtils.InitializeArmies()
  ScenarioFramework.SetPlayableArea('AREA_1' , false)
end

   -- Resoure Matrix script (c) Micdah
   local ScenarioUtils = import('/lua/sim/ScenarioUtilities.lua')
   
   -- ResourceType
   -- defines which resource types are available, and the settings for each
   local ResourceType = {
   	Mass = {
   		UID = 0,
   		typeName = "Mass",
   		sizeX = 2,
   		sizeZ = 2,
   		size = 1.00,
   		albedo = "/env/common/splats/mass_marker.dds",
   		prop = "/env/common/props/massDeposit01_prop.bp",
   		lod = 100,
   	},
   	Hydrocarbon = {
   		UID = 2,
   		typeName = "Hydrocarbon",
   		sizeX = 6,
   		sizeZ = 6,
   		size = 3.00,
   		albedo = "/env/common/splats/hydrocarbon_marker.dds",
   		prop = "/env/common/props/hydrocarbonDeposit01_prop.bp",
   		lod = 200,
   	},
   }
   
   -- Create a single resource marker at given coordinates
   -- @param (ResourceType)mType,	Which resource to use
   -- @param (float)x,			X-coordinate for marker
   -- @param (float)y,			Y-coordinate for marker
   -- @param (float)z,			Z-coordinate for marker
   -- @return null				No return
   local function CreateResource(mType,x,y,z)
   	-- Create Resource
   	CreateResourceDeposit(mType.typeName, x, y, z, mType.size);
   	
   	-- Create resource graphic on map
   	CreatePropHPR(mType.prop, x, y, z, Random(0,360), 0, 0);
   	
   	-- Create resource icon on map
   	CreateSplat(VECTOR3(x, y, z), 0, mType.albedo, mType.sizeX, mType.sizeZ, mType.lod, 0, -1, 0);
   end
   
   -- Create a resource matrix
   -- @param (float)startX, 		X coordinate for top-left corner of matrix
   -- @param (float)y, 			Y coordinate for the matrix (all markers are placed in the same z-level)
   -- @param (float)startZ, 		Z coordinate for top-left corner of matrix
   -- @param (float)spaceX, 		Spacing between markers along the x-axis, for perfect alignment use ResourceType.Type.sizeX
   -- @param (float)spaceZ,		Spacing between markers along the z-axis, for perfect alignment use ResourceType.Type.sizeZ
   -- @param (int)rows,			Number of rows in matrix
   -- @param (int)columns,			Number of columns in matrix
   -- @param (ResourceType)mType,	Which resource to use in matrix
   -- @return null				No return
   local function CreateResourceMatrix(mType, startX, y, startZ, spaceX, spaceZ, rows, columns)
   	local tmpX = 0.00;
   	local tmpZ = 0.00;
   	local row, column;
   	
   	for row=0, (rows-1), 1 do
   		for column=0, (columns-1), 1 do
   			tmpX = startX + (column * spaceX);
   			tmpZ = startZ + (row * spaceZ);
   			
   			--- Create resource
   			CreateResource(mType, tmpX, y, tmpZ);
   		end
   	end
   end
   
   -- Get army position
   -- @param (string)mName,	Name of army, ex. ARMY_1
   -- @return {x,y,z},			Returns object with x,y,z coordinates		
   local function GetArmyPosition(mName)
   	return {
   		x = Scenario.MasterChain['_MASTERCHAIN_'].Markers[mName]['position'][1],
   		y = Scenario.MasterChain['_MASTERCHAIN_'].Markers[mName]['position'][2],
   		z = Scenario.MasterChain['_MASTERCHAIN_'].Markers[mName]['position'][3],
   	}
   end
   
   function OnStart(self)
   	-- Create mass resource matrixes for each player
   	-- CreateResourceMatrix(ResourceType.Mass, 55.50, 64.00, 55.50, 2.00, 2.00, 4, 5);
   	local rows = ScenarioInfo.Options.opt_mass_rows;
   	local columns = ScenarioInfo.Options.opt_mass_cols;
   	local army, p;
   	local p = {
   		army1 = GetArmyPosition('ARMY_1'),
   		army2 = GetArmyPosition('ARMY_2'),
   		army3 = GetArmyPosition('ARMY_3'),
   		army4 = GetArmyPosition('ARMY_4'),
   		army5 = GetArmyPosition('ARMY_5'),
   		army6 = GetArmyPosition('ARMY_6'),
   		army7 = GetArmyPosition('ARMY_7'),
   		army8 = GetArmyPosition('ARMY_8'),
   	}
   	
	CreateResourceMatrix(ResourceType.Mass, p.army1.x, p.army1.y, p.army1.z, 4.00, 4.00, rows, columns);
   	CreateResourceMatrix(ResourceType.Mass, p.army2.x, p.army2.y, p.army2.z, 4.00, 4.00, rows, columns);
   	CreateResourceMatrix(ResourceType.Mass, p.army3.x, p.army3.y, p.army3.z, 4.00, 4.00, rows, columns);
   	CreateResourceMatrix(ResourceType.Mass, p.army4.x, p.army4.y, p.army4.z, 4.00, 4.00, rows, columns);
   	CreateResourceMatrix(ResourceType.Mass, p.army5.x, p.army5.y, p.army5.z, 4.00, 4.00, rows, columns);
   	CreateResourceMatrix(ResourceType.Mass, p.army6.x, p.army6.y, p.army6.z, 4.00, 4.00, rows, columns);
   	CreateResourceMatrix(ResourceType.Mass, p.army7.x, p.army7.y, p.army7.z, 4.00, 4.00, rows, columns);
 	CreateResourceMatrix(ResourceType.Mass, p.army8.x, p.army8.y, p.army8.z, 4.00, 4.00, rows, columns);
   end